#! /bin/sh
#
# skeleton	example file to build /etc/init.d/ scripts.
#		This file should be used to construct scripts for /etc/init.d.
#
#		Written by Miquel van Smoorenburg <miquels@cistron.nl>.
#		Modified for Debian
#		by Ian Murdock <imurdock@gnu.ai.mit.edu>.
#               Further changes by Javier Fernandez-Sanguino <jfs@debian.org>
#
# Version:	@(#)skeleton  1.9  26-Feb-2001  miquels@cistron.nl
#

### BEGIN INIT INFO
# Provides:          deliverance
# Required-Start:    $network $local_fs
# Required-Stop:
# Should-Start:      $named
# Should-Stop:
# Default-Start:     2 3 4 5
# Default-Stop:      0 1 6
# Short-Description: <Enter a short description of the sortware>
# Description:       <Enter a long description of the software>
#                    <...>
#                    <...>
### END INIT INFO

PATH=/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin
DAEMON=/usr/bin/deliverance-proxy
NAME=deliverance

test -x $DAEMON || exit 0

DEFAULT_RULES=/etc/deliverance/rules.xml
PIDFILE=/var/run/$NAME.pid
DODTIME=1                   # Time to wait for the server to die, in seconds
                            # If this value is set too low you might not
                            # let some servers to die gracefully and
                            # 'restart' will not work

# Include deliverance defaults if available
if [ -f /etc/default/deliverance ] ; then
	. /etc/default/deliverance
fi

set -e

guessconfig () {
        [ -f "$DEFAULT_RULES" ] || {
            echo "Could not find rules file rules.xml to use in /etc/deliverance."
            exit 1
        }
}

case "$1" in 
    debug)
        echo -n "Starting $NAME"
        guessconfig
        /sbin/start-stop-daemon --start --make-pidfile --pidfile $PIDFILE \
            --startas $DAEMON --chuid nobody -- $DEFAULT_RULES

        echo "."
        ;;
    start)
        echo -n "Starting $NAME"
        guessconfig
        /sbin/start-stop-daemon --start --make-pidfile --pidfile $PIDFILE --background \
            --startas $DAEMON --chuid nobody -- $DEFAULT_RULES

        echo "."
        ;;
    stop)
        echo -n "Stopping $NAME"
        guessconfig
        /sbin/start-stop-daemon --stop --pidfile $PIDFILE --chuid nobody || echo -n " (not running)"

        echo "."
        ;;
    restart)
        echo -n "Restarting $NAME"
        guessconfig
        /sbin/start-stop-daemon --stop --pidfile $PIDFILE --chuid nobody || echo -n " (not running)"

        /sbin/start-stop-daemon --start --make-pidfile --pidfile $PIDFILE --background \
            --startas $DAEMON --chuid nobody -- $DEFAULT_RULES

        echo "."
        ;;
    *)
        N=/etc/init.d/$NAME
        echo "Usage: $N {start|stop|restart}" >&2
        exit 1
        ;;

esac

exit 0
